bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 11. Aventiure
___________________________________________________ #### Auentv wie Sifrit sin wip heim ze lande fvrte #### vn– wie <er> sit da heime brvotten
| ### SVon der Sigemundes mit gvtlichem site ### sprach zv sinen heleden tvot des ich ivch bite ### nv bereit vns die moere ia wil ich in min lant ### liep was ez sime wibe do si div mære an im ervant ### Si sprach zv dem herren sit wir von hinnen varn ### daz ich so harte gahe daz heiz ich wol bewarn ### mir suln e mine bruoder teilen mit div lant ### leit was ez Sivride do erz an Chriemh' <ervant>
###### 701 | ### Die fuorsten zv zim giengen vn– sprachen <alle> dri ### nv wizzet daz herre Sivrit daz iv immer si ### mit <triwen> vnser dienest bereit vnz in den tot ### des neiger do den degenen do manz im so wol erbot
###### 702 | ### Wir suln ovch mit iv teilen sprach Giselher daz kint ### lant vn– burge die unser eigen sint ### swaz der witen erbe vns ist undertan ### der svlt ir teil vil gvten mit samt <Chriemh'> han
| ### Zv sinen chonemagen do der reche sprach ### do er den gvten willen an den herren sach ### got laze iv iwer erbe immer [27r]selic sin ### vn– ovch die lute drinne ia tvot div wine min
###### 704 | ### des teiles wol ze rate den ir ir woldet gebn ### da si da sol tragen chrone vn– svln wir daz gelebn ### si mvoz <werden> richer dann iemen lebender <si> ### swaz ir svs gebietet sten ich iv dienstlichen bi
###### 705 | ### Do sprach div frowe Chriemh' habt ir der erbe rat ### vmbe Buregonden degene ez so lihte niene stat ### sine mvge ein chunich gerne fvren in sin lant ### ia sol si mit mir teilen miner lieben bruder hant
###### 706 | ### Do sprach der herre <Gernot> nv nim dir swen dv wil ### die mit dir gerne riten der vindestv vil ### von drizech hundert rechen so habe dir tusint man ### die sin din heimgesinde daz was ir liebe getan
###### 707 | ### Si bereite sich zir verte als ir vil wol gezam ### ir edeln ingesindes frov Chriemh' do nam ### zwo un– drizzech mægede dar zvo funfhvndert man ### Ecgewart der grave fvr mit siner frowen dan
| ### Vrlovp si alle namen beide ritter vn– kneht ### <mægede> vn– frowen daz was vil michel reht ### mit chvssen gescheiden wrden si zehant ### si rovmten minnekliche do der Buregonden lant
###### 709 | ### Do beleiten si ir mage vil verre vf den wegen ### man hiezin allenthalben ir nahtselde legn ### swa si si gerne namen dvrch der chunige lant ### do wrden boten balde dem kunige Sigemvnt gesant
###### 710 | ### daz er daz wizzen solde vn– ovch Sigelint ### daz Sivrit chomen wolde vn– ovch frown Voten kint ### Chriemh' div vil schone von Wormez vber Rin ### done kunden in div mêre nimmer lieber gesin
###### 711 | ### Nv wol mich sprach do Sigemvnt daz ich gelebt han ### daz hie div schone Chriemhilt sol gechronet <stan> ### des mvezen wol getivret sin div erbe min ### Sivrit der vil chuene sol hie nv selbe voget sin
###### 712 | ### Do gap div frowe Sigelint vil manigen samyt rot ### silber vn– golt daz swêre daz was ir botenbrot ### si vrevte sich der mære vn– mit ir manic man ### allez ir gesinde mit vlize <chleiden> sich began
| ### Man seit ir wer da choeme mit Sivride in daz lant ### do <hiezen> si gesidele <rihten> alzehant ### dar zv er vnder chrone vor fvrsten solde gan ### do riten im engegene des kunich Sigemundes man
###### 714 | ### Ist iemen baz enpfangen daz ist vns vnbechant ### denne die helede wrden ze Sigemundes lant ### Sigelint sin mvoter Chriemh' engegen reit ### mit maniger schonen frowen ir volgeten ritter gemeit
###### 715 | ### in einer tageweide da man die geste sach ### die vremeden vn– dic chvnden die dolten vngemach ### vnz daz si chomen zer burge wol bechant ### riche vn– mære div was ze Santen genant
###### 716 | ### Mitt lachendem mvnde Sigelint vn– Sigemvnt ### chusten Chriemh' mit vrovden sa zehant ### darnach ir vil liebez kint ir leit in was benomen ### allez ir gesinde was in groz willechomen
###### 717 | ### Do brahte man die geste fvr Segemvndes sal ### die schone iuncfrowen [27v]hvben man da zetal ### nider von den moeren da was vil manic man ### do man den edeln frowen mit vlize dienen began
| ### Swie groz ir hochgeciten bi Rine was bechant ### noch gab man hie den heleden richer gewant ### danne si ie getrvegen noh bi allen ir tagen ### man mohte michel wnder von ir richeite sagn
###### 719 | ### Do si in ir wirde sazen vn– heten genvoch ### waz golt varwer geren ir ingesinde trvoch ### vn– vil der edeln steine verwieret wol dar in ### svs pflag ir vlizzekliche Sigelint div kvnigin
###### 720 | ### Do sprach vor sinen mâgen der herre Sigemvnt ### allen minen frivnden sol daz wesn chvnt ### daz Sivrit mine chrone hinnen fvr sol tragn ### div mære horten gerne die von Niderlanden sagn
###### 721 | ### Do bevalhe er im die chrone geriht vn– ovch div lant ### sit was er ir aller meister die er inder vant ### vn– da er rihten solde daz wart so getan ### daz man von schulden vorhte der schonen Chriemh' man
| ### In disen hohen eren lebt er daz ist war ### vn– riht ovch vnder chrone vnz in daz zwelfte iar ### daz div schone <Chriemh'> einen svn gewan ### daz was des kuniges magen nach ir willen wol ergan
###### 723 | ### Den ilte man do tavfen vn– gab im den namen ### Gunther nach sinem oheim des dorfter sich niht schamen ### geriet er nach den magen er wrde ein chvner man ### man zoh in wol mit vlize daz wart von schulden getan
###### 724 | ### In den selben citen do starp frov Sigelint ### do het den gewalt mit alle der edeln Voten kint ### der so richer frowen ob landen wol gezam ### di mohten ir do dienen mit grozen eren ane scham
| ### Nv het ovch dort bi Rine so wir horen sagen ### bi Gunther dem richen einen svn getragen ### Prvnhilt div schone in Burgonden lant ### dvrch des rechen liebe so wart er Sivrit genant
###### 726 | ### Wie rehte vlizekliche man sin hvten hiez ### Gunther der vil riche im magtzogen liez ### diez chunden leren tvgende gewhs ez zeinem man ### hey waz im vngelvche sit der mage an gewan
###### 727 | ### Mære zallen citen wart <wider> vn– dar geseit ### wie rehte wnnekliche die helde vil gemeit ### lebten zallen stvnden in Sigemundes lant ### daz selbe tet ovch Gvnther mit sinen <magen> vz erchant
###### 728 | ### Daz lant ze Nibelunge Sivride nv diente hie ### richer siner mage wart deheiner nie ### dar zv sins vaters erbe ein was ein degn gvot ### des trvch der vil chune deste hoher den mvot
| ### Hort den aller meisten den ie kunic gewan ### ane die ez e pflagn hete nv der chune man ### den er vor einem berge mit siner hant erstreit ### dar vmber slvoc ze tode vil manigen ritter gemeit
###### 730 | ### Er het den wnsch der eren vn– wæres niht geschehn ### so mvse man von <schulden> Sivride iehn ### er ware ein der beste der ie vf ors gesaz ### man vorhte sine sterche vn– tet vil pilliche daz

<<< Übersicht <<< vorige Seite nächste Seite >>>